# stylizers

### An Extraordinary Styling Library

This library is used to style your beautiful into an extraordinary styled name.

# Usage

To use this library the following sample code is given below

```
import stylizers

style_name = stylizers.stylo("Divyanshu")
print(style_name)
```

Here we've used the function `stylo()` which will styled your name.
It uses the default style. The parameter of this function is your name.

To customise your name the following sample code is given below:

```
import stylizers

custom_name = stylizers.styeriment("Divyanshu", "🐍", "🐯", "🏵️")
print(custom_name)
```

Here we've used the function `styeriment()`
The parameters of this function are:
* your_name
* emoji_inner: The Emoji which is used to style the background.
* emoji_center: The Emoji which is used to style your alphabet character.
* emoji_outer: The Emoji which is used to style the border.

**To experiment with the name style use `styeriment()` function and for default style use `stylo()` function.**

# Requirements

1. Python version should be 3.0+.
2. pip should be updated to the latest version. To upgrade pip use `pip install --upgrade pip`.

# Installation

To install this library in your PC you just have to follow the instructions given below:

1. First open your `command prompt` for Windows 10 users open your `PowerShell`.
2. It must that Python is installed in your PC and Path variable in the environment.
3. To install it write `pip install stylizers` in your command prompt. It takes few seconds in the installation process.

Bravo, we've installed this library in our PC.
Now, just go and play with it in your `Python IDE`.

> Python is a very beautiful, easy and powerful language that anyone could understand.
> Mastering in Python is much easier than other languages.

# GitHub Links

#### My Profile Link
[Divyanshu Singh](https://github.com/DivyanshuSingh96)

#### Repository Link
[stylizers](https://github.com/DivyanshuSingh96/stylizers)

Made with 🐍 by Divyanshu Singh
